#!/usr/bin/env bash

set -x

if [[ "$(uname)" == 'Linux' ]]; then
    _os_name=linux

    install -D /bin/sed $BUILD_PREFIX/bin/sed
else
    _os_name=macos
fi

./build.sh --no-gui

mkdir -p $PREFIX/opt/renode/bin
mkdir -p $PREFIX/opt/renode/scripts
mkdir -p $PREFIX/opt/renode/platforms
mkdir -p $PREFIX/opt/renode/tests
mkdir -p $PREFIX/opt/renode/tools
mkdir -p $PREFIX/opt/renode/licenses


cp .renode-root $PREFIX/opt/renode/
cp -r output/bin/Release/* $PREFIX/opt/renode/bin/
cp -r scripts/* $PREFIX/opt/renode/scripts/
cp -r platforms/* $PREFIX/opt/renode/platforms/
cp -r tests/* $PREFIX/opt/renode/tests/
cp -r tools/metrics_analyzer $PREFIX/opt/renode/tools
cp -r tools/gdb_compare $PREFIX/opt/renode/tools
cp -r tools/sel4_extensions $PREFIX/opt/renode/tools

cp lib/resources/styles/robot.css $PREFIX/opt/renode/tests
cp tests/requirements.txt $PREFIX/opt/renode/tests
cp src/Renode/RobotFrameworkEngine/renode-keywords.robot $PREFIX/opt/renode/tests
cp src/Renode/RobotFrameworkEngine/helper.py $PREFIX/opt/renode/tests


tools/packaging/common_copy_licenses.sh $PREFIX/opt/renode/licenses $_os_name


sed -i.bak 's#os\.path\.join(this_path, "\.\./src/Renode/RobotFrameworkEngine/renode-keywords\.robot")#os.path.join(this_path,"renode-keywords.robot")#g' $PREFIX/opt/renode/tests/robot_tests_provider.py
sed -i.bak "s#os\.path\.join(this_path, '\.\./lib/resources/styles/robot\.css')#os.path.join(this_path,'robot.css')#g" $PREFIX/opt/renode/tests/robot_tests_provider.py
rm $PREFIX/opt/renode/tests/robot_tests_provider.py.bak

mkdir -p $PREFIX/bin/

cat > $PREFIX/bin/renode <<"EOF"
#!/usr/bin/env bash

mono $MONO_OPTIONS $CONDA_PREFIX/opt/renode/bin/Renode.exe "$@"
EOF

cat > $PREFIX/bin/renode-test <<"EOF"
#!/usr/bin/env bash

STTY_CONFIG=`stty -g 2>/dev/null`
python3 $CONDA_PREFIX/opt/renode/tests/run_tests.py --robot-framework-remote-server-full-directory $CONDA_PREFIX/opt/renode/bin "$@"
RESULT_CODE=$?
if [ -n "${STTY_CONFIG:-}" ]
then
    stty "$STTY_CONFIG"
fi
exit $RESULT_CODE
EOF

mkdir -p "${PREFIX}/etc/conda/activate.d"
cp "${RECIPE_DIR}/activate.sh" "${PREFIX}/etc/conda/activate.d/${PKG_NAME}_activate.sh"

